==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkMySQLQuery.java <==
// java wrapper for vtkMySQLQuery object
//

package vtk;
import vtk.*;

public class vtkMySQLQuery extends vtkSQLQuery
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean SetQuery_2(String id0);
  public boolean SetQuery(String id0)
    { return SetQuery_2(id0); }

  private native boolean Execute_3();
  public boolean Execute()
    { return Execute_3(); }

  private native boolean BeginTransaction_4();
  public boolean BeginTransaction()
    { return BeginTransaction_4(); }

  private native boolean CommitTransaction_5();
  public boolean CommitTransaction()
    { return CommitTransaction_5(); }

  private native boolean RollbackTransaction_6();
  public boolean RollbackTransaction()
    { return RollbackTransaction_6(); }

  private native int GetNumberOfFields_7();
  public int GetNumberOfFields()
    { return GetNumberOfFields_7(); }

  private native String GetFieldName_8(int id0);
  public String GetFieldName(int id0)
    { return GetFieldName_8(id0); }

  private native int GetFieldType_9(int id0);
  public int GetFieldType(int id0)
    { return GetFieldType_9(id0); }

  private native boolean NextRow_10();
  public boolean NextRow()
    { return NextRow_10(); }

  private native boolean HasError_11();
  public boolean HasError()
    { return HasError_11(); }

  private native String GetLastErrorText_12();
  public String GetLastErrorText()
    { return GetLastErrorText_12(); }

  private native boolean BindParameter_13(int id0,char id1);
  public boolean BindParameter(int id0,char id1)
    { return BindParameter_13(id0,id1); }

  private native boolean BindParameter_14(int id0,double id1);
  public boolean BindParameter(int id0,double id1)
    { return BindParameter_14(id0,id1); }

  private native boolean BindParameter_15(int id0,String id1);
  public boolean BindParameter(int id0,String id1)
    { return BindParameter_15(id0,id1); }

  private native boolean ClearParameterBindings_16();
  public boolean ClearParameterBindings()
    { return ClearParameterBindings_16(); }

  private native String EscapeString_17(String id0,boolean id1);
  public String EscapeString(String id0,boolean id1)
    { return EscapeString_17(id0,id1); }

  public vtkMySQLQuery() { super(); }

  public vtkMySQLQuery(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-armv6h.pkg.tar.xz: vtk/vtkMySQLQuery.java <==
// java wrapper for vtkMySQLQuery object
//

package vtk;
import vtk.*;

public class vtkMySQLQuery extends vtkSQLQuery
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean SetQuery_2(String id0);
  public boolean SetQuery(String id0)
    { return SetQuery_2(id0); }

  private native boolean Execute_3();
  public boolean Execute()
    { return Execute_3(); }

  private native boolean BeginTransaction_4();
  public boolean BeginTransaction()
    { return BeginTransaction_4(); }

  private native boolean CommitTransaction_5();
  public boolean CommitTransaction()
    { return CommitTransaction_5(); }

  private native boolean RollbackTransaction_6();
  public boolean RollbackTransaction()
    { return RollbackTransaction_6(); }

  private native int GetNumberOfFields_7();
  public int GetNumberOfFields()
    { return GetNumberOfFields_7(); }

  private native String GetFieldName_8(int id0);
  public String GetFieldName(int id0)
    { return GetFieldName_8(id0); }

  private native int GetFieldType_9(int id0);
  public int GetFieldType(int id0)
    { return GetFieldType_9(id0); }

  private native boolean NextRow_10();
  public boolean NextRow()
    { return NextRow_10(); }

  private native boolean HasError_11();
  public boolean HasError()
    { return HasError_11(); }

  private native String GetLastErrorText_12();
  public String GetLastErrorText()
    { return GetLastErrorText_12(); }

  private native boolean BindParameter_13(int id0,char id1);
  public boolean BindParameter(int id0,char id1)
    { return BindParameter_13(id0,id1); }

  private native boolean BindParameter_14(int id0,double id1);
  public boolean BindParameter(int id0,double id1)
    { return BindParameter_14(id0,id1); }

  private native boolean BindParameter_15(int id0,String id1);
  public boolean BindParameter(int id0,String id1)
    { return BindParameter_15(id0,id1); }

  private native boolean ClearParameterBindings_16();
  public boolean ClearParameterBindings()
    { return ClearParameterBindings_16(); }

  private native String EscapeString_17(String id0,boolean id1);
  public String EscapeString(String id0,boolean id1)
    { return EscapeString_17(id0,id1); }

  public vtkMySQLQuery() { super(); }

  public vtkMySQLQuery(long id) { super(id); }
  public native long   VTKInit();

}
